@@ -256,14 +256,14 @@ class MainWindow():
         self.window.add_accel_group(accel_group)
         menu = self.builder.get_object("main_menu")
         item = Gtk.ImageMenuItem()
-        item.set_image(Gtk.Image.new_from_icon_name("help-about-symbolic", Gtk.IconSize.MENU))
+        item.set_image(Gtk.Image.new_from_icon_name("xsi-help-about-symbolic", Gtk.IconSize.MENU))
         item.set_label(_("About"))
         item.connect("activate", self.open_about)
         key, mod = Gtk.accelerator_parse("F1")
         item.add_accelerator("activate", accel_group, key, mod, Gtk.AccelFlags.VISIBLE)
         menu.append(item)
         item = Gtk.ImageMenuItem(label=_("Quit"))
-        image = Gtk.Image.new_from_icon_name("application-exit-symbolic", Gtk.IconSize.MENU)
+        image = Gtk.Image.new_from_icon_name("xsi-exit-symbolic", Gtk.IconSize.MENU)
         item.set_image(image)
         item.connect('activate', self.on_menu_quit)
         key, mod = Gtk.accelerator_parse("<Control>Q")
@@ -438,13 +438,13 @@ class MainWindow():
         dlg.set_program_name("Bulky")
         dlg.set_comments(_("Rename Files"))
         try:
-            with open('/usr/share/common-licenses/GPL', encoding="utf-8") as h:
+            with open('/usr/share/common-licenses/GPL-3', encoding="utf-8") as h:
                 gpl= h.read()
             dlg.set_license(gpl)
         except Exception as e:
             print (e)
 
-        dlg.set_version("3.9")
+        dlg.set_version("4.0")
         dlg.set_icon_name("bulky")
         dlg.set_logo_icon_name("bulky")
         dlg.set_website("https://www.github.com/linuxmint/bulky")
@@ -752,15 +752,21 @@ class MainWindow():
             return string
 
     def remove_text(self, index, string):
-        length = len(string) - 1
-        from_index = min(self.remove_from_spin.get_value_as_int() - 1, length)
-        to_index = min(self.remove_to_spin.get_value_as_int() - 1, length)
+        length = len(string)
+
+        from_index = self.remove_from_spin.get_value_as_int() - 1
         if self.remove_from_check.get_active():
-            from_index = length - from_index
+            from_index = max(length - from_index, 0)
+        else:
+            from_index = min(length, from_index)
+
+        to_index = self.remove_to_spin.get_value_as_int() - 1
         if self.remove_to_check.get_active():
-            to_index = length - to_index
-        to_index = max(to_index + 1, from_index)
-        return string[0:from_index]+string[to_index:]
+            to_index = max(length - to_index, 0)
+        else:
+            to_index = min(length, to_index)
+
+        return string[0:min(from_index, to_index)] + string[max(from_index, to_index):]
 
     def insert_text(self, index, string):
         text = self.insert_entry.get_text()
